==> 0.0.63.tar.gz: lib/Controller/baseController.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:get/get.dart';
import 'package:wowit/firebaseService.dart';

import '../baseModel.dart';

class BaseController extends GetxController {
  Map<String, Object> conditions = {};
  Map<String, Object> parameter = {};
  Map<String, bool> orderBy = {};
  int limit = -1;
  String collection = "";

  BaseController(
      {this.collection,
      this.conditions,
      this.orderBy,
      this.limit,
      this.parameter});

  @override
  void update([List<Object> ids, bool condition = true]) {
    // TODO: implement update
    super.update(ids, condition);
    print(this.runtimeType.toString() + ' - BaseController on update');
  }

  @override
  void onClose() {
    // TODO: implement onClose
    super.onClose();
    print(this.runtimeType.toString() + ' - BaseController on onClose');
  }

  @override
  void onReady() {
    // TODO: implement onReady
    super.onReady();
    print(this.runtimeType.toString() + ' - BaseController on onReady');
  }

  @override
  void onInit() {
    // TODO: implement onInit
    super.onInit();
    print(this.runtimeType.toString() +
        ' - BaseController on onInit with condition');
    print(this.conditions);
  }

  Stream<List<BaseModel>> onBindStream() {
    // TODO: implement onInit
    print(this.runtimeType.toString() +
        ' - BaseController on onBindStream - conditions');
    if (this.parameter != null && this.parameter.length > 0) {
      this.parameter.forEach((key, value) {
        this.conditions[key] = value;
      });
    }
    print(this.conditions);

    return FirebaseService.getQuery(this.collection,
            conditions: conditions, orderBy: this.orderBy, limit: this.limit)
        .snapshots()
        .map((QuerySnapshot query) {
      List<BaseModel> retVal = [];
      query.docs.forEach((element) {
        retVal.add(toModel(element));
      });
      return onBeforeReturnResult(retVal);
    });
  }

  BaseModel toModel(DocumentSnapshot element) {
    return new BaseModel(element);
  }

  List<BaseModel> onBeforeReturnResult(List<BaseModel> retVal) {
    return retVal;
  }
}

==> 0.0.64.tar.gz: lib/Controller/baseController.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:get/get.dart';
import 'package:wowit/firebaseService.dart';

import '../baseModel.dart';

class BaseController extends GetxController {
  Map<String, Object> conditions;

  Map<String, Object> parameter;

  Map<String, bool> orderBy;

  int limit;

  String collection;

  BaseController(
      {this.collection = '',
      this.conditions,
      this.orderBy,
      this.limit = -1,
      this.parameter}) {
    this.conditions ??= {};
    this.orderBy ??= {};
    this.parameter ??= {};
  }

  @override
  void update([List<Object> ids, bool condition = true]) {
    // TODO: implement update
    super.update(ids, condition);
    print(this.runtimeType.toString() + ' - BaseController on update');
  }

  @override
  void onClose() {
    // TODO: implement onClose
    super.onClose();
    print(this.runtimeType.toString() + ' - BaseController on onClose');
  }

  @override
  void onReady() {
    // TODO: implement onReady
    super.onReady();
    print(this.runtimeType.toString() + ' - BaseController on onReady');
  }

  @override
  void onInit() {
    // TODO: implement onInit
    super.onInit();
    print(this.runtimeType.toString() +
        ' - BaseController on onInit with condition');
    print(this.conditions);
  }

  Stream<List<BaseModel>> onBindStream() {
    // TODO: implement onInit
    print(this.runtimeType.toString() +
        ' - BaseController on onBindStream - conditions');
    if (this.parameter != null && this.parameter.length > 0) {
      this.parameter.forEach((key, value) {
        this.conditions[key] = value;
      });
    }
    print(this.conditions);
    if (this.collection == '') {
      throw ("[ERROR] Collection is empty");
    }
    return FirebaseService.getQuery(this.collection,
            conditions: conditions, orderBy: this.orderBy, limit: this.limit)
        .snapshots()
        .map((QuerySnapshot query) {
      List<BaseModel> retVal = [];
      query.docs.forEach((element) {
        retVal.add(toModel(element));
      });
      return onBeforeReturnResult(retVal);
    });
  }

  BaseModel toModel(DocumentSnapshot element) {
    return new BaseModel(element);
  }

  List<BaseModel> onBeforeReturnResult(List<BaseModel> retVal) {
    return retVal;
  }
}
